@@ -26,7 +26,8 @@ namespace Kicker
 {
 
 enum {
-    HasChildrenRole = Qt::UserRole +1,
+    IsParentRole = Qt::UserRole + 1,
+    HasChildrenRole,
     FavoriteIdRole,
     HasActionListRole,
     ActionListRole,
@@ -43,4 +44,4 @@ QVariantList createActionListForFileItem(const KFileItem &fileItem);
 
 bool handleFileItemAction(const KFileItem &fileItem, const QString &actionId, const QVariant &argument, bool *close);
 
-}
\ No newline at end of file
+}
