@@ -21,7 +21,17 @@
 #include "actionlist.h"
 #include "appsmodel.h"
 
+#include <config-X11.h>
+
+#if HAVE_X11
+#include <QX11Info>
+#endif
+
+#include <KConfigGroup>
+#include <KMimeTypeTrader>
 #include <KRun>
+#include <KSharedConfig>
+#include <KStartupInfo>
 
 FavoritesModel::FavoritesModel(QObject *parent) : AbstractModel(parent)
 , m_sourceModel(0)
@@ -84,13 +94,20 @@ bool FavoritesModel::trigger(int row, const QString &actionId, const QVariant &a
     } else if (m_serviceCache.contains(favoritesId)) {
         KService::Ptr service = m_serviceCache[favoritesId];
 
-        bool ran = KRun::run(*service, QList<QUrl>(), 0);
+        quint32 timeStamp = 0;
 
-        if (ran) {
-            emit appLaunched(service->storageId());
+#if HAVE_X11
+        if (QX11Info::isPlatformX11()) {
+            timeStamp = QX11Info::appUserTime();
         }
+#endif
 
-        return ran;
+        new KRun(QUrl::fromLocalFile(service->entryPath()), 0, true,
+            KStartupInfo::createNewStartupIdForTimestamp(timeStamp));
+
+        emit appLaunched(service->storageId());
+
+        return true;
     }
 
     return false;
@@ -116,7 +133,13 @@ void FavoritesModel::setFavorites(const QStringList& favorites)
             while (i.hasNext()) {
                 i.next();
 
-                service = KService::serviceByStorageId(i.value());
+                QUrl url(i.value());
+
+                if (url.isValid() && url.scheme() == QLatin1String("preferred")) {
+                    service = defaultAppByName(url.host());
+                } else {
+                    service = KService::serviceByStorageId(i.value());
+                }
 
                 if (service) {
                     i.setValue(service->storageId());
@@ -161,10 +184,17 @@ void FavoritesModel::addFavorite(const QString &favoriteId)
     QString _favoriteId = favoriteId;
 
     if (!m_sourceModel) {
-        KService::Ptr service = KService::serviceByStorageId(favoriteId);
+        KService::Ptr service;
+        QUrl url(_favoriteId);
+
+        if (url.isValid() && url.scheme() == QLatin1String("preferred")) {
+            service = defaultAppByName(url.host());
+        } else {
+            service = KService::serviceByStorageId(_favoriteId);
+            _favoriteId = service->storageId();
+        }
 
         if (service) {
-            _favoriteId = service->storageId();
             m_serviceCache[_favoriteId] = service;
         } else {
             return;
@@ -244,3 +274,20 @@ void FavoritesModel::refresh()
      setFavorites(m_favorites);
 }
 
+KService::Ptr FavoritesModel::defaultAppByName(const QString& name)
+{
+    if (name == QLatin1String("browser")) {
+        KConfigGroup config(KSharedConfig::openConfig(), "General");
+        QString browser = config.readPathEntry("BrowserApplication", QString());
+
+        if (browser.isEmpty()) {
+            return KMimeTypeTrader::self()->preferredService(QLatin1String("text/html"));
+        } else if (browser.startsWith('!')) {
+            browser = browser.mid(1);
+        }
+
+        return KService::serviceByStorageId(browser);
+    }
+
+    return KService::Ptr();
+}
