@@ -19,52 +19,38 @@
 
 #include "systemsettings.h"
 
-#include <QApplication>
-#include <QEvent>
+#include <QGuiApplication>
 #include <QStyle>
+#include <QStyleHints>
 #include <QWidget>
 
 SystemSettings::SystemSettings(QObject *parent) : QObject(parent),
-    m_monitoredWidget(new QWidget())
+    m_widget(new QWidget())
 {
-    m_monitoredWidget->resize(0, 0);
-    m_monitoredWidget->hide();
-
-    m_monitoredWidget->installEventFilter(this);
+    m_widget->resize(0, 0);
+    m_widget->hide();
 }
 
 SystemSettings::~SystemSettings()
 {
-    delete m_monitoredWidget;
+    delete m_widget;
 }
 
 bool SystemSettings::singleClick() const
 {
-    return m_monitoredWidget->style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick);
+    // FIXME TODO: Check back for whether this eventually got added to
+    // QGuiApplication::styleHints() / Qt.styleHints.
+    return m_widget->style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick);
 }
 
 int SystemSettings::doubleClickInterval() const
 {
-    if (!qApp) {
-        return 400;
-    }
-
-    return qApp->doubleClickInterval();
+    return QGuiApplication::styleHints()->mouseDoubleClickInterval();
 }
 
 bool SystemSettings::isDrag(int oldX, int oldY, int newX, int newY) const
 {
-    return ((QPoint(oldX, oldY) - QPoint(newX, newY)).manhattanLength() >= QApplication::startDragDistance());
-}
-
-
-bool SystemSettings::eventFilter(QObject *watched, QEvent *event)
-{
-    Q_UNUSED(watched)
-
-    if (event->type() == QEvent::StyleChange) {
-        emit singleClickChanged();
-    }
-
-    return false;
+    // FIXME TODO: QGuiApplication::styleHints() will be available as
+    // Qt.styleHints in QML starting with Qt 5.5.
+    return ((QPoint(oldX, oldY) - QPoint(newX, newY)).manhattanLength() >= QGuiApplication::styleHints()->startDragDistance());
 }
