@@ -1,3 +1,24 @@
+/*
+    Copyright 2000 Matthias Hölzer-Klüpfel <hoelzer@kde.org>
+    Copyright 2014 Frederik Gladhorn <gladhorn@kde.org>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+*/
+
 #include <unistd.h>
 
 #include "kaccess.h"
@@ -42,7 +63,7 @@ struct ModifierKey {
    const char *unlatchedText;
 };
 
-static ModifierKey modifierKeys[] = {
+static const ModifierKey modifierKeys[] = {
     { ShiftMask, 0, "Shift",
       I18N_NOOP("The Shift key has been locked and is now active for all of the following keypresses."),
       I18N_NOOP("The Shift key is now active."),
@@ -99,7 +120,7 @@ KAccessApp::KAccessApp(bool allowStyles, bool GUIenabled)
   overlay(0), _player(0)
 {
   _activeWindow = KWindowSystem::activeWindow();
-  connect(KWindowSystem::self(), SIGNAL(activeWindowChanged(WId)), this, SLOT(activeWindowChanged(WId)));
+  connect(KWindowSystem::self(), &KWindowSystem::activeWindowChanged, this, &KAccessApp::activeWindowChanged);
 
   features = 0;
   requestedFeatures = 0;
@@ -115,14 +136,14 @@ KAccessApp::KAccessApp(bool allowStyles, bool GUIenabled)
 
 int KAccessApp::newInstance()
 {
-  KGlobal::config()->reparseConfiguration();
+  KSharedConfig::openConfig()->reparseConfiguration();
   readSettings();
   return 0;
 }
 
 void KAccessApp::readSettings()
 {
-  KSharedConfig::Ptr _config = KGlobal::config();
+  KSharedConfig::Ptr _config = KSharedConfig::openConfig();
   KConfigGroup cg(_config, "Bell");
 
   // bell ---------------------------------------------------------------
@@ -492,14 +513,14 @@ QString mouseKeysShortcut (Display *display) {
      sym = XK_Pointer_EnableKeys;
      code = XKeysymToKeycode(display, sym);
      if (code == 0)
-        return ""; // No shortcut available?
+        return QString(); // No shortcut available?
   }
 
   // Calculate the modifiers by searching the keysym in the X keyboard mapping
   XkbDescPtr xkbdesc = XkbGetMap(display, XkbKeyTypesMask | XkbKeySymsMask, XkbUseCoreKbd);
 
   if (!xkbdesc)
-      return ""; // Failed to obtain the mapping from server
+      return QString(); // Failed to obtain the mapping from server
 
   bool found = false;
   unsigned char modifiers = 0;
@@ -528,7 +549,7 @@ QString mouseKeysShortcut (Display *display) {
   XkbFreeClientMap (xkbdesc, 0, true);
 
   if (!found)
-     return ""; // Somehow the keycode -> keysym mapping is flawed
+     return QString(); // Somehow the keycode -> keysym mapping is flawed
 
   XEvent ev;
   ev.type = KeyPress;
@@ -615,7 +636,7 @@ void KAccessApp::createDialogContents() {
       QVBoxLayout * vlay = new QVBoxLayout();
       lay->addItem( vlay );
 
-      featuresLabel = new QLabel( "", contents );
+      featuresLabel = new QLabel( QString(), contents );
       featuresLabel->setAlignment( Qt::AlignVCenter );
       featuresLabel->setWordWrap( true );
       vlay->addWidget( featuresLabel );
@@ -637,9 +658,9 @@ void KAccessApp::createDialogContents() {
 
       dialog->setMainWidget(topcontents);
 
-      connect (dialog, SIGNAL(yesClicked()), this, SLOT(yesClicked()));
-      connect (dialog, SIGNAL(noClicked()), this, SLOT(noClicked()));
-      connect (dialog, SIGNAL(closeClicked()), this, SLOT(dialogClosed()));
+      connect(dialog, &KDialog::yesClicked, this, &KAccessApp::yesClicked);
+      connect(dialog, &KDialog::noClicked, this, &KAccessApp::noClicked);
+      connect(dialog, &KDialog::closeClicked, this, &KAccessApp::dialogClosed);
    }
 }
 
@@ -822,7 +843,7 @@ void KAccessApp::applyChanges() {
    unsigned int enabled  = requestedFeatures & ~features;
    unsigned int disabled = features & ~requestedFeatures;
 
-   KConfigGroup config(KGlobal::config(), "Keyboard");
+   KConfigGroup config(KSharedConfig::openConfig(), "Keyboard");
 
    if (enabled & XkbSlowKeysMask)
       config.writeEntry("SlowKeys", true);
@@ -839,7 +860,7 @@ void KAccessApp::applyChanges() {
    else if (disabled & XkbStickyKeysMask)
       config.writeEntry("StickyKeys", false);
 
-   KConfigGroup mousegrp(KGlobal::config(),"Mouse");
+   KConfigGroup mousegrp(KSharedConfig::openConfig(),"Mouse");
 
    if (enabled & XkbMouseKeysMask)
       mousegrp.writeEntry("MouseKeys", true);
@@ -854,7 +875,7 @@ void KAccessApp::yesClicked() {
       dialog->deleteLater();
    dialog = 0;
 
-   KConfigGroup config(KGlobal::config(), "Keyboard");
+   KConfigGroup config(KSharedConfig::openConfig(), "Keyboard");
    switch (showModeCombobox->currentIndex()) {
       case 0:
          config.writeEntry("Gestures", true);
@@ -884,7 +905,7 @@ void KAccessApp::noClicked() {
    dialog = 0;
    requestedFeatures = features;
 
-   KConfigGroup config(KGlobal::config(), "Keyboard");
+   KConfigGroup config(KSharedConfig::openConfig(), "Keyboard");
    switch (showModeCombobox->currentIndex()) {
       case 0:
          config.writeEntry("Gestures", true);
@@ -918,4 +939,3 @@ void KAccessApp::setXkbOpcode(int opcode) {
    xkb_opcode = opcode;
 }
 
-#include "kaccess.moc"
