@@ -14,13 +14,11 @@
  ***************************************************************************/
 
 #include "componentchooserterminal.h"
-#include "componentchooserterminal.moc"
 
 #include <ktoolinvocation.h>
 #include <QtDBus/QtDBus>
 #include <QCheckBox>
 
-#include <kdebug.h>
 #include <kapplication.h>
 #include <klocale.h>
 #include <kmessagebox.h>
@@ -42,10 +40,10 @@ CfgTerminalEmulator::CfgTerminalEmulator(QWidget *parent)
     : QWidget(parent), Ui::TerminalEmulatorConfig_UI(), CfgPlugin()
 {
 	setupUi(this);
-	connect(terminalLE,SIGNAL(textChanged(QString)), this, SLOT(configChanged()));
-	connect(terminalCB,SIGNAL(toggled(bool)),this,SLOT(configChanged()));
-	connect(otherCB,SIGNAL(toggled(bool)),this,SLOT(configChanged()));
-	connect(btnSelectTerminal,SIGNAL(clicked()),this,SLOT(selectTerminalApp()));
+	connect(terminalLE, &QLineEdit::textChanged, this, &CfgTerminalEmulator::configChanged);
+	connect(terminalCB, &QRadioButton::toggled, this, &CfgTerminalEmulator::configChanged);
+	connect(otherCB, &QRadioButton::toggled, this, &CfgTerminalEmulator::configChanged);
+	connect(btnSelectTerminal, &QToolButton::clicked, this, &CfgTerminalEmulator::selectTerminalApp);
 
 }
 
