@@ -52,8 +52,7 @@
 // clears it. So we have to use a reasonable default.
 static const QString exePath = QLatin1String("/usr/sbin:/usr/bin:/sbin:/bin");
 
-int ClockHelper::ntp( const QStringList& ntpServers, bool ntpEnabled,
-                      const QString& ntpUtility )
+int ClockHelper::ntp( const QStringList& ntpServers, bool ntpEnabled )
 {
     int ret = 0;
 
@@ -69,6 +68,11 @@ int ClockHelper::ntp( const QStringList& ntpServers, bool ntpEnabled,
     config.writeEntry("servers", ntpServers );
     config.writeEntry("enabled", ntpEnabled );
 
+    QString ntpUtility = QStandardPaths::findExecutable("ntpdate");
+    if (ntpUtility.isEmpty()) {
+        ntpUtility = QStandardPaths::findExecutable("rdate");
+    }
+
     if ( ntpEnabled && !ntpUtility.isEmpty() ) {
         // NTP Time setting
         QString timeServer = ntpServers.first();
@@ -110,6 +114,13 @@ int ClockHelper::date( const QString& newdate, const QString& olddate )
 int ClockHelper::tz( const QString& selectedzone )
 {
     int ret = 0;
+
+    //only allow letters, numbers hyphen underscore plus and forward slash
+    //allowed pattern taken from time-util.c in systemd
+    if (!QRegExp("[a-zA-Z0-9-_+/]*").exactMatch(selectedzone)) {
+        return ret;
+    }
+
     QString val;
 #if defined(USE_SOLARIS)	// MARCO
     KTemporaryFile tf;
@@ -234,7 +245,7 @@ ActionReply ClockHelper::save(const QVariantMap &args)
     int ret = 0; // error code
     //  The order here is important
     if( _ntp )
-        ret |= ntp( args.value("ntpServers").toStringList(), args.value("ntpEnabled").toBool(), args.value("ntpUtility").toString() );
+        ret |= ntp( args.value("ntpServers").toStringList(), args.value("ntpEnabled").toBool());
     if( _date )
         ret |= date( args.value("newdate").toString(), args.value("olddate").toString() );
     if( _tz )
