@@ -60,9 +60,15 @@ KCMFormats::~KCMFormats()
     delete m_ui;
 }
 
+bool countryLessThan(const QLocale & c1, const QLocale & c2)
+{
+    return QString::localeAwareCompare(c1.nativeCountryName(), c2.nativeCountryName()) < 0;
+}
+
 void KCMFormats::load()
 {
-    const QList<QLocale> allLocales = QLocale::matchingLocales(QLocale::AnyLanguage, QLocale::AnyScript, QLocale::AnyCountry);
+    QList<QLocale> allLocales = QLocale::matchingLocales(QLocale::AnyLanguage, QLocale::AnyScript, QLocale::AnyCountry);
+    qSort(allLocales.begin(), allLocales.end(), countryLessThan);
     foreach(QComboBox * combo, m_combos) {
         initCombo(combo, allLocales);
     }
@@ -92,7 +98,6 @@ void KCMFormats::initCombo(QComboBox *combo, const QList<QLocale> & allLocales)
     foreach(const QLocale & l, allLocales) {
         addLocaleToCombo(combo, l);
     }
-    combo->model()->sort(0);
 }
 
 void KCMFormats::connectCombo(QComboBox *combo)
@@ -119,7 +124,7 @@ void KCMFormats::addLocaleToCombo(QComboBox *combo, const QLocale &locale)
     if (split.count() > 1) {
         flagcode = split[1].toLower();
     }
-    QString flag(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("locale/l10n/%1/flag.png").arg(flagcode)));
+    QString flag(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf5/locale/countries/%1/flag.png").arg(flagcode)));
     QIcon flagIcon;
     if (!flag.isEmpty()) {
         flagIcon = QIcon(flag);
