@@ -19,15 +19,13 @@
 
 #include "kcm_keyboard.h"
 
-#include <kdebug.h>
 #include <kaboutdata.h>
 #include <kpluginfactory.h>
-#include <kpluginloader.h>
+//#include <kpluginloader.h>
 #include <KLocalizedString>
-#include <KDialog>
 
-#include <QtDBus/QDBusMessage>
-#include <QtDBus/QDBusConnection>
+#include <QDBusMessage>
+#include <QDBusConnection>
 //#include <QtDBus/QDBusInterface>
 
 #include "kcm_keyboard_widget.h"
@@ -43,7 +41,6 @@
 
 
 K_PLUGIN_FACTORY(KeyboardModuleFactory, registerPlugin<KCMKeyboard>();)
-K_EXPORT_PLUGIN(KeyboardModuleFactory("kcmkeyboard"))
 
 KCMKeyboard::KCMKeyboard(QWidget *parent, const QVariantList &args)
   : KCModule(parent)
@@ -64,7 +61,7 @@ KCMKeyboard::KCMKeyboard(QWidget *parent, const QVariantList &args)
 
   QVBoxLayout *layout = new QVBoxLayout(this);
   layout->setMargin(0);
-  layout->setSpacing(KDialog::spacingHint());
+//  layout->setSpacing(KDialog::spacingHint());
 
   widget = new KCMKeyboardWidget(rules, keyboardConfig, args, parent);
   layout->addWidget(widget);
