@@ -24,18 +24,16 @@
 #include "config-workspace.h"
 #include "Viewer.h"
 #include "KfiConstants.h"
-#include <KConfigGroup>
 #include <KCmdLineArgs>
 #include <k4aboutdata.h>
 #include <KUniqueApplication>
 #include <KPluginLoader>
 #include <KPluginFactory>
-#include <KGlobal>
 #include <KFileDialog>
-#include <KConfig>
 #include <KStandardAction>
 #include <KActionCollection>
 #include <KShortcutsDialog>
+#include <KConfigGroup>
 #include <KParts/BrowserExtension>
 #include <QUrl>
 #include <QAction>
