@@ -41,6 +41,8 @@ class KCMLookandFeel : public KCModule
     Q_PROPERTY(bool applyWidgetStyle READ applyWidgetStyle WRITE setApplyWidgetStyle NOTIFY applyWidgetStyleChanged)
     Q_PROPERTY(bool applyIcons READ applyIcons WRITE setApplyIcons NOTIFY applyIconsChanged)
     Q_PROPERTY(bool applyPlasmaTheme READ applyPlasmaTheme WRITE setApplyPlasmaTheme NOTIFY applyPlasmaThemeChanged)
+    Q_PROPERTY(bool applyWindowSwitcher READ applyWindowSwitcher WRITE setApplyWindowSwitcher NOTIFY applyWindowSwitcherChanged)
+    Q_PROPERTY(bool applyDesktopSwitcher READ applyDesktopSwitcher WRITE setApplyDesktopSwitcher NOTIFY applyDesktopSwitcherChanged)
 
 public:
     enum Roles {
@@ -54,7 +56,9 @@ public:
         HasWidgetStyleRole,
         HasIconsRole,
         HasPlasmaThemeRole,
-        HasCursorsRole
+        HasCursorsRole,
+        HasWindowSwitcherRole,
+        HasDesktopSwitcherRole
     };
     KCMLookandFeel(QWidget* parent, const QVariantList& args);
     ~KCMLookandFeel();
@@ -74,6 +78,8 @@ public:
     void setCursorTheme(const QString theme);
     void setSplashScreen(const QString &theme);
     void setLockScreen(const QString &theme);
+    void setWindowSwitcher(const QString &theme);
+    void setDesktopSwitcher(const QString &theme);
 
     void setApplyColors(bool apply);
     bool applyColors() const;
@@ -83,6 +89,10 @@ public:
     bool applyIcons() const;
     void setApplyPlasmaTheme(bool apply);
     bool applyPlasmaTheme() const;
+    void setApplyWindowSwitcher(bool apply);
+    bool applyWindowSwitcher() const;
+    void setApplyDesktopSwitcher(bool apply);
+    bool applyDesktopSwitcher() const;
 
 public Q_SLOTS:
     void load();
@@ -96,6 +106,8 @@ Q_SIGNALS:
     void applyWidgetStyleChanged();
     void applyIconsChanged();
     void applyPlasmaThemeChanged();
+    void applyWindowSwitcherChanged();
+    void applyDesktopSwitcherChanged();
 
 private:
     QDir cursorThemeDir(const QString &theme, const int depth);
@@ -114,6 +126,8 @@ private:
     bool m_applyIcons : 1;
     bool m_applyPlasmaTheme : 1;
     bool m_applyCursors : 1;
+    bool m_applyWindowSwitcher : 1;
+    bool m_applyDesktopSwitcher : 1;
 };
 
 #endif
